## Full usage

```
Usage: whirled_peas <command> [command options]

Available commands:

    debug     Print template tree for specified frame
    fonts     List installed title fonts with sample text
    frames    Print out list of frames generated by application
    help      Show detailed help for a command
    play      Play an animation from an application or prerecorded file
    record    Record animation to a file
    still     Show the specified still frame
    themes    List all themes with sample template rendered in the theme
```

### `debug`

Print the template tree for specified frame.

```
# Usage: whirled_peas debug <config file> <frame> [args as a JSON string]
% whirled_peas debug my_app.rb greeting '{"name":"World"}'
* WhirledPeas::Graphics::BoxPainter(TEMPLATE)
  - Dimensions(outer=140x27, content=120x15, grid=1x1)
  - Settings
    WhirledPeas::Settings::BoxSettings
      padding: Padding(left: 10, top: 6, right: 10, bottom: 6)
      align: :center
      width: 120
      flow: :t2b
      bold: true
      bg_color: BgColor(code=107, bright=true)
  - Children
    * WhirledPeas::Graphics::BoxPainter(Element-1)
      - Dimensions(outer=64x6, content=64x6, grid=1x1)
```

### `fonts`

List all installed title fonts with sample text.

```
# Usage: whirled_peas fonts
```

### `frames`

Print out list of frames generated by application.

```
# Usage: whirled_peas frames <config file>
% whirled_peas frames my_app.rb
Frame 'intro' displayed for 3 second(s) '{"title":"Foo"}'
Frame 'greet' displayed for 0.3 second(s)
...
```

### `help`

Print out command-specific help message

```
Usage: whirled_peas help <command>
```

### `play`

Play an animation from an application or prerecorded file

```
# Usage: whirled_peas play <config/wpz file>

# Play animation directly from app
% whirled_peas play my_app.rb
# Animation plays

# Play animation from previously recorded file
% whirled_peas play my_animation.wpz
# Animation plays
```

### `record`

Record animation to a file

```
# Usage: whirled_peas record <config file> <output file>
% whirled_peas record my_app.rb my_animation.wpz
# Record animation to my_animation.wpz
```

### `still`

Show the specified still frame

```
# Usage: whirled_peas still <config file> <frame> [args as a JSON string]
% whirled_peas still my_app.rb greeting '{"name":"World"}'
# Still frame is displayed
```

### `themes`

List all themes and display a small sample screen in each. Running this with no extra command line arguments will display all the built-in themes. Adding the path to a Whirled Peas configuration file will inlcude any themes defined in that configuration.

```
# Usage: whirled_peas themes [config file]
% whirled_peas themes
# Display all system themes

% whirled_peas themes my_app.rb
# Display app-defined themes and all system themes
```
